.. h5torch documentation master file, created by
   sphinx-quickstart on Tue Apr  4 13:08:09 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to h5torch's documentation!
===================================
HDF5 Data utilities for PyTorch.

.. include:: ../../README.md
   :parser: myst_parser.sphinx_

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   Tutorial <tutorial>
   API Reference <h5torch>


..
   Indices and tables
   ==================

..
   * :ref:`genindex`
   * :ref:`modindex`
   * :ref:`search`
